<?php
get_header();
$post_type = get_post_type();
$current_term = get_queried_object(); 
$paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
// Set up the query arguments
$args = array(
    'post_type' => $post_type,
    'posts_per_page' => 9,
    'paged' => $paged,
    'orderby' => 'date',
    'order' => 'DESC',
);

//var_dump($current_term);

// If we're on a specific term page, add the tax query
if (is_tax('konkursy-kategoria') && $current_term instanceof WP_Term) {
    $args['tax_query'] = array(
        array(
            'taxonomy' => 'konkursy-kategoria',
            'field'    => 'slug',
            'terms'    => $current_term->slug,
        ),
    );
}

$query = new WP_Query($args);
?>
    <section class="sub-page-header">
        <div class="container">
            <div class="row">
                <div class="col-12">
                    <?php custom_breadcrumbs(); ?>
                    <div class="content template-excerpt">
                        <div class="web-heading heading-divider secondary">
                            <h1><?php esc_html_e($current_term->name, 'Kolejowe'); ?></h1>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <main class="main-wrap">
        <div class="container">
            <!-- Posts Grid -->
            <div class="row">
                <?php
                if ($query->have_posts()) :
                    while ($query->have_posts()) : $query->the_post();
                        $thumbnail_id = get_post_thumbnail_id(get_the_ID());
                        $thumbnail_alt = get_post_meta($thumbnail_id, '_wp_attachment_image_alt', true);
                        $alt_text = $thumbnail_alt ? $thumbnail_alt : get_the_title();
                        ?>
                        <div class="col-md-4 mb-4">
                            <div class="article-card competition-card">
                                <div class="article-featured-img">
                                    <?php if (has_post_thumbnail()) : ?>
                                        <?php the_post_thumbnail('full', array(
                                            'alt' => esc_attr($alt_text),
                                            'aria-hidden' => 'true'
                                        )); ?>
                                    <?php endif; ?>
                                </div>
                                <div class="article-content">
                                    <div class="article-top">
                                        <h5><?php the_title(); ?></h5>
                                        <div class="excerpt-sec">
                                            <?php
                                            $excerpt = has_excerpt() ? get_the_excerpt() : wp_trim_words(get_the_content(), 20);
                                            ?>
                                            <p><?php echo esc_html($excerpt); ?></p>
                                        </div>
                                    </div>
                                    <div class="article-bottom">
                                        <div class="meta-date">
                                            <?php echo get_the_date(); ?>
                                        </div>
                                        <div class="web-btn d-flex">
                                            <a href="<?php the_permalink(); ?>" class="link-btn">
                                                <span><?php esc_html_e('Czytaj artykuł', 'Kolejowe'); ?></span>
                                                <div class="icon">
                                                    <img decoding="async" 
                                                        src="<?php echo esc_url(get_template_directory_uri()); ?>/images/right-arrow-circle.svg" 
                                                        alt="icon" 
                                                        aria-hidden="true">
                                                </div>
                                            </a>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    <?php
                    endwhile;
                    ?>
                    <!-- Pagination -->
                    <div class="pagination-wrap d-flex align-items-center justify-content-center">
                        <div class="pagination-inner" role="navigation">
                            <?php
                            echo paginate_links(array(
                                'total' => $query->max_num_pages,
                                'current' => $paged,
                                'prev_text' => '&#x1F860;',
                                'next_text' => '&#x1F862;',
                            ));
                            ?>
                        </div>
                    </div>
                    <?php
                    wp_reset_postdata();
                else : ?>
                    <div class="col-12">
                        <p><?php esc_html_e('Nie znaleziono postów w tej kategorii.', 'Kolejowe'); ?></p>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </main>
<?php get_footer();
