<?php 
    $title = get_field('title');
    $description = get_field('description');
    $buttonEnable = get_field('ukryj_przycisk');
    $button = get_field('nazwa_na_przycisku');
    $url = get_field('adres_przycisku');

    $atts = shortcode_atts(
        array(
            'post_type' => 'event',
            'posts_per_page' => -1,
            'categories' => 'event-category', // Default to no category filter
        ),
        $atts
    );

    $html_to_return = ''; // Initialize the variable

    ob_start();

    $post_type = sanitize_text_field($atts['post_type']);
    $posts_per_page = intval($atts['posts_per_page']);
    $posts_categories = intval($atts['categories']);

    $args = array(
        'post_type' => $post_type,
        'posts_per_page' =>$posts_per_page,
        'cat' =>  $posts_categories,
    );

    $custom_query = new WP_Query($args);
        $index = 0;
    $eventsArray = [];
    if ($custom_query->have_posts()) : 
        while ($custom_query->have_posts()) : 
            $custom_query->the_post();
            $rawDate = get_post_meta(get_the_ID(), 'event_date', true);
            $formattedDate = DateTime::createFromFormat('Ymd', $rawDate)->format('Y-m-d');

            $eventsArray[] = [
                'title' => get_the_title(),
                'date' => $formattedDate,
                'time' => get_post_meta(get_the_ID(), 'event_time', true),
                'place' => get_post_meta(get_the_ID(), 'place', true),
                'url' => get_permalink(),
                'button' => 'Obejrzyj fotorelację'
            ];
    
        endwhile;
    endif;

    $eventsJson = json_encode($eventsArray);

    //var_dump($eventsJson);
   
?>
<section class="calendar-section">
	<div class="container">
		<div class="row align-items-center">
			<div class="col-lg-4">
				<?php if( $title ) : ?>
				<h2><?php echo $title; ?></h2>
				<?php endif; ?>
				<div class="event-desc">
					<?php if( $description ) : ?>
					<?php echo $description; ?>
					<?php endif; ?>
				</div>
				<div class="events-detail"></div>
			</div>
			<div class="col-lg-8">
				<div id="calendar" class="event-calendar"></div>
				<?php if( $buttonEnable ) : ?>
				<div class="web-btn d-flex my-4">
					<a href="<?php echo $url; ?>" class="link-btn">
						<span><?php echo esc_html_e($button, 'Kolejowe'); ?></span>
						<div class="icon">
							<img decoding="async" src="<?php echo get_template_directory_uri(); ?>/images/right-arrow-circle.svg" alt="icon" aria-hidden="true">
						</div>
					</a>
				</div>
				<?php endif; ?>
			</div>
		</div>
	</div>
</section>
<script>
function initializeCalendar() {
    var eventsArray = <?php echo $eventsJson; ?>;
    // Count events per day
    var eventsPerDay = {};
    eventsArray.forEach(event => {
        eventsPerDay[event.date] = (eventsPerDay[event.date] || 0) + 1;
    });

    var calendarEvents = Object.keys(eventsPerDay).map(date => ({
        title: `${eventsPerDay[date]} ${getEventLabel(eventsPerDay[date])}`, // Show total events count
        start: date,
        allDay: true
    }));

    eventsArray.forEach(event => {
        calendarEvents.push({
            title: event.title,
            start: event.date,
            extendedProps: {
                time: event.time,
                place: event.place,
                url: event.url,
                button: event.button
            }
        });
    });

    var calendarEl = document.getElementById('calendar');
    var calendar = new FullCalendar.Calendar(calendarEl, {
        locale: 'pl',
        themeSystem: 'bootstrap5',
        initialView: 'dayGridMonth',
        views: {
            dayGridMonth: {
                dayHeaderFormat: {
                    weekday: 'long'
                }
            }
        },
        firstDay: 1,
        editable: false,
        headerToolbar: {
            left: 'prev,title',
            //center: 'month,agendaWeek,agendaDay',
            right: 'next'
        },
        buttonIcons: {
            prev: 'chevron-left',
            next: 'chevron-right',
        },
        events: calendarEvents,
        eventContent: function (info) {
            if (info.event.extendedProps.time) {
                return null; // Skip rendering individual events
            }
            return { html: `<div class="fc-total-event-cell" data-date="${info.event.startStr}">${info.event.title}</div>` };
        },
        dateClick: function (info) {
            // Remove 'active' class from all days
            document.querySelectorAll('.fc-daygrid-day').forEach(function (day) {
                day.classList.remove('fc-day-active');
            });
            // Add 'active' class to the clicked day
            info.dayEl.classList.add('fc-day-active');
            showEventsForDay(info.dateStr, calendarEvents);
        }
    });
    calendar.render();

    // Handle clicks on event labels
    document.addEventListener('click', function (e) {
        if (e.target.classList.contains('fc-total-event-cell')) {
            const clickedDate = e.target.getAttribute('data-date');
            // Find the matching date cell
            const dayCell = document.querySelector(`[data-date="${clickedDate}"]`);
            if (dayCell) {
                // Trigger a click event on the date cell
                dayCell.dispatchEvent(new Event('click', { bubbles: true }));
            }
        }
    });
}
function formatDateToDMY(dateString) {
    const date = new Date(dateString);
    const day = String(date.getDate()).padStart(2, '0');
    const month = String(date.getMonth() + 1).padStart(2, '0'); // Months are 0-based
    const year = date.getFullYear();
    return `${day}.${month}.${year}`;
}
// Show events for a specific day in the events-detail div
function showEventsForDay(date, events) {
    const today = new Date().toISOString().split('T')[0];
    
    var eventsForDay = events.filter(event => event.start === date);
    var detailDiv = $('.events-detail');
    var eventDesc = $('.event-desc');
    detailDiv.empty();

    const fomratedDate = formatDateToDMY(date);

    if (eventsForDay.length > 0) {
        eventDesc.addClass('has-results').html('<p>Wydarzenia w dniu: '+ fomratedDate +'</p>');

        eventsForDay.forEach(event => {
            if( event.allDay ) {

            } else {
                //console.log(event);

                const isPastEvent = event.start < today;
                const fomratedDate = formatDateToDMY(event.start);

                var eventHtml = `
                    <div class="event-details">
                        <h6 class="event-title">${event.title}</h6>
                        <div class="event-bottom">
                            <div class="event-date">
                                <svg xmlns="http://www.w3.org/2000/svg" width="25" height="25" viewBox="0 0 25 25" fill="none"><path d="M17.2502 3.60785V2.04785C17.2502 1.63785 16.9102 1.29785 16.5002 1.29785C16.0902 1.29785 15.7502 1.63785 15.7502 2.04785V3.54785H9.25023V2.04785C9.25023 1.63785 8.91023 1.29785 8.50023 1.29785C8.09023 1.29785 7.75023 1.63785 7.75023 2.04785V3.60785C5.05023 3.85785 3.74023 5.46785 3.54023 7.85785C3.52023 8.14785 3.76023 8.38785 4.04023 8.38785H20.9602C21.2502 8.38785 21.4902 8.13785 21.4602 7.85785C21.2602 5.46785 19.9502 3.85785 17.2502 3.60785Z" fill="#042B60"/><path d="M20.5 9.88794H4.5C3.95 9.88794 3.5 10.3379 3.5 10.8879V17.0479C3.5 20.0479 5 22.0479 8.5 22.0479H16.5C20 22.0479 21.5 20.0479 21.5 17.0479V10.8879C21.5 10.3379 21.05 9.88794 20.5 9.88794ZM9.71 18.2579C9.66 18.2979 9.61 18.3479 9.56 18.3779C9.5 18.4179 9.44 18.4479 9.38 18.4679C9.32 18.4979 9.26 18.5179 9.2 18.5279C9.13 18.5379 9.07 18.5479 9 18.5479C8.87 18.5479 8.74 18.5179 8.62 18.4679C8.49 18.4179 8.39 18.3479 8.29 18.2579C8.11 18.0679 8 17.8079 8 17.5479C8 17.2879 8.11 17.0279 8.29 16.8379C8.39 16.7479 8.49 16.6779 8.62 16.6279C8.8 16.5479 9 16.5279 9.2 16.5679C9.26 16.5779 9.32 16.5979 9.38 16.6279C9.44 16.6479 9.5 16.6779 9.56 16.7179C9.61 16.7579 9.66 16.7979 9.71 16.8379C9.89 17.0279 10 17.2879 10 17.5479C10 17.8079 9.89 18.0679 9.71 18.2579ZM9.71 14.7579C9.52 14.9379 9.26 15.0479 9 15.0479C8.74 15.0479 8.48 14.9379 8.29 14.7579C8.11 14.5679 8 14.3079 8 14.0479C8 13.7879 8.11 13.5279 8.29 13.3379C8.57 13.0579 9.01 12.9679 9.38 13.1279C9.51 13.1779 9.62 13.2479 9.71 13.3379C9.89 13.5279 10 13.7879 10 14.0479C10 14.3079 9.89 14.5679 9.71 14.7579ZM13.21 18.2579C13.02 18.4379 12.76 18.5479 12.5 18.5479C12.24 18.5479 11.98 18.4379 11.79 18.2579C11.61 18.0679 11.5 17.8079 11.5 17.5479C11.5 17.2879 11.61 17.0279 11.79 16.8379C12.16 16.4679 12.84 16.4679 13.21 16.8379C13.39 17.0279 13.5 17.2879 13.5 17.5479C13.5 17.8079 13.39 18.0679 13.21 18.2579ZM13.21 14.7579C13.16 14.7979 13.11 14.8379 13.06 14.8779C13 14.9179 12.94 14.9479 12.88 14.9679C12.82 14.9979 12.76 15.0179 12.7 15.0279C12.63 15.0379 12.57 15.0479 12.5 15.0479C12.24 15.0479 11.98 14.9379 11.79 14.7579C11.61 14.5679 11.5 14.3079 11.5 14.0479C11.5 13.7879 11.61 13.5279 11.79 13.3379C11.88 13.2479 11.99 13.1779 12.12 13.1279C12.49 12.9679 12.93 13.0579 13.21 13.3379C13.39 13.5279 13.5 13.7879 13.5 14.0479C13.5 14.3079 13.39 14.5679 13.21 14.7579ZM16.71 18.2579C16.52 18.4379 16.26 18.5479 16 18.5479C15.74 18.5479 15.48 18.4379 15.29 18.2579C15.11 18.0679 15 17.8079 15 17.5479C15 17.2879 15.11 17.0279 15.29 16.8379C15.66 16.4679 16.34 16.4679 16.71 16.8379C16.89 17.0279 17 17.2879 17 17.5479C17 17.8079 16.89 18.0679 16.71 18.2579ZM16.71 14.7579C16.66 14.7979 16.61 14.8379 16.56 14.8779C16.5 14.9179 16.44 14.9479 16.38 14.9679C16.32 14.9979 16.26 15.0179 16.2 15.0279C16.13 15.0379 16.06 15.0479 16 15.0479C15.74 15.0479 15.48 14.9379 15.29 14.7579C15.11 14.5679 15 14.3079 15 14.0479C15 13.7879 15.11 13.5279 15.29 13.3379C15.39 13.2479 15.49 13.1779 15.62 13.1279C15.8 13.0479 16 13.0279 16.2 13.0679C16.26 13.0779 16.32 13.0979 16.38 13.1279C16.44 13.1479 16.5 13.1779 16.56 13.2179C16.61 13.2579 16.66 13.2979 16.71 13.3379C16.89 13.5279 17 13.7879 17 14.0479C17 14.3079 16.89 14.5679 16.71 14.7579Z" fill="#042B60"/></svg> 
                                <span class="text"> ${fomratedDate}</span>
                            </div>
                             ${event.extendedProps.time ? `
                                <div class="event-time">
                                    <svg xmlns="http://www.w3.org/2000/svg" width="25" height="25" viewBox="0 0 25 25" fill="none"><path d="M12.5 2.54785C6.99 2.54785 2.5 7.03785 2.5 12.5479C2.5 18.0579 6.99 22.5479 12.5 22.5479C18.01 22.5479 22.5 18.0579 22.5 12.5479C22.5 7.03785 18.01 2.54785 12.5 2.54785ZM16.85 16.1179C16.71 16.3579 16.46 16.4879 16.2 16.4879C16.07 16.4879 15.94 16.4579 15.82 16.3779L12.72 14.5279C11.95 14.0679 11.38 13.0579 11.38 12.1679V8.06785C11.38 7.65785 11.72 7.31785 12.13 7.31785C12.54 7.31785 12.88 7.65785 12.88 8.06785V12.1679C12.88 12.5279 13.18 13.0579 13.49 13.2379L16.59 15.0879C16.95 15.2979 17.07 15.7579 16.85 16.1179Z" fill="#042B60"/></svg> 
                                    <span class="text"> ${event.extendedProps.time}</span>
                                </div>
                            ` : ''}
                            ${event.extendedProps.place ? `
                                <div class="event-place">
                                    <svg xmlns="http://www.w3.org/2000/svg" width="25" height="25" viewBox="0 0 25 25" fill="none"><path d="M21.1201 8.99785C20.0701 4.37785 16.0401 2.29785 12.5001 2.29785C12.5001 2.29785 12.5001 2.29785 12.4901 2.29785C8.9601 2.29785 4.9201 4.36785 3.8701 8.98785C2.7001 14.1479 5.8601 18.5179 8.7201 21.2679C9.7801 22.2879 11.1401 22.7979 12.5001 22.7979C13.8601 22.7979 15.2201 22.2879 16.2701 21.2679C19.1301 18.5179 22.2901 14.1579 21.1201 8.99785ZM12.5001 14.0079C10.7601 14.0079 9.3501 12.5979 9.3501 10.8579C9.3501 9.11785 10.7601 7.70785 12.5001 7.70785C14.2401 7.70785 15.6501 9.11785 15.6501 10.8579C15.6501 12.5979 14.2401 14.0079 12.5001 14.0079Z" fill="#042B60"/></svg>
                                    <span class="text"> ${event.extendedProps.place}</span>
                                </div>
                            ` : ''}
                        </div>
                        ${isPastEvent ? `
                            <div class="web-btn d-flex mb-3 justify-content-end">
                                <a href="${event.extendedProps.url}" class="link-btn">
                                    <span>${event.extendedProps.button}</span>
                                    <div class="icon">
                                        <img decoding="async" src="<?php echo get_template_directory_uri(); ?>/images/right-arrow-circle.svg" alt="icon" aria-hidden="true">
                                    </div>
                                </a>
                            </div>
                        ` : ''}
                    </div>
                `;
                detailDiv.append(eventHtml);   
            }
        });
    } else {
        eventDesc.removeClass('has-results').html('<p>W wybranym dniu nie ma żadnych wydarzeń. Wybierz inny dzień.</p>');
    }
}
// Function to get the correct label for the event count
function getEventLabel(count) {
    if (count === 1) {
        return "wydarzenie"; // Singular
    } else if (count >= 2 && count <= 4) {
        return "wydarzenia"; // Plural (2-4)
    } else {
        return "wydarzeń"; // Plural (5 and above)
    }
}
// Check if FullCalendar is loaded
function loadCalendarCustomScript() {
    //const checkInterval = setInterval(() => {
        if (typeof FullCalendar !== 'undefined') {
            initializeCalendar();
        } else {
            console.error('FullCalendar is not loaded!');
        }
    //}, 2000); // Check every 100ms

}

$(document).ready(function() {
	loadCalendarCustomScript();
});
</script>
<style>
    .calendar-section .event-desc.has-results + .events-detail {
        max-height: 400px;
        overflow: hidden auto;
    }
    .calendar-section .event-desc p {
        max-width: 80%;
        color: var(--primary-color);
        font-size: 24px;
        line-height: 34px;
        font-weight: 600;
    }
    .calendar-section .event-desc.has-results p {
        max-width: 100%;
        margin-bottom: 15px;
    }
    .calendar-section .event-details .event-title {
        font-weight: 600;
        color: var(--primary-color);
        font-size: 22px;
        line-height: 33px;
        margin-bottom: 15px;
        font-family: "Figtree", sans-serif;
    }
    .calendar-section .event-bottom {
        display: flex;
        flex-wrap: wrap;
        gap: 0px 15px;
    }
    .calendar-section .event-bottom > div {
        display: inline-flex;
        align-items: center;
        gap: 10px;
        margin-bottom: 15px;
        line-height: normal;
        color: var(--primary-color);
    }
    .calendar-section .event-details:not(:last-child) {
        border-bottom: 1px solid #A5D7D9;
        margin-bottom: 20px;
    }
    .fc .fc-col-header-cell-cushion {
        display: inline-block;
        padding: 2px 4px;
        color: #454545;
        font-weight: 500;
        text-transform: uppercase;
        font-size: 14px;
    }
    .fc-theme-standard td, .fc-theme-standard th {
        border: none;
        overflow: hidden;
        background: transparent !important;
        background-color: transparent !important;
        position: relative;
        z-index: 9;
    }
    .fc-theme-standard .fc-scrollgrid {
        border: none;
    }
    .fc .fc-scrollgrid-section-liquid > td, .fc-theme-standard .fc-scrollgrid {
        padding: 0;
    }
    .fc-scrollgrid-sync-table td {
        padding: 4px;
    }
    /* .fc .fc-daygrid-day.fc-day-today .fc-daygrid-day-frame {
        background-color: var(--fc-today-bg-color);
    } */
    .fc .fc-daygrid-day-frame {
        min-height: 100%;
        position: relative;
        /* margin: 5px !important; */
        border-radius: 10px;
        padding: 5px;
        cursor: pointer;
    }
    .fc .fc-day-other .fc-daygrid-day-frame {
        background: #7272720F;
    }
    .fc .fc-day-other .fc-daygrid-day-top {
        opacity: 1;
    }
    .fc .fc-daygrid-day-number {
        color: #454545;
        font-size: 16px;
        line-height: normal;
    }
    .fc .fc-daygrid-day-top {
        flex-direction: row;
    }
    .fc .fc-daygrid-day:not(.fc-day-other) .fc-daygrid-day-number {
        color: #042B60;
    }
    .fc .fc-daygrid-day:not(.fc-day-other) .fc-daygrid-day-frame {
        background: #00C0B50F;
    }
    .fc-h-event {
        background-color: transparent;
        border: none;
        display: flex;
        border-radius: 0px !important;
        padding: 0px;
        position: relative;
        z-index: -1 !important;
    }
    .fc .fc-day-sat:not(.fc-day-other) .fc-daygrid-day-frame, .fc .fc-day-sun:not(.fc-day-other) .fc-daygrid-day-frame {
        background: #DC04510A !important;
    }
    .fc .fc-daygrid-day-events {
        z-index: 5;
    }
    .fc-h-event .fc-event-main {
        width: 100%;
    }
    .fc-h-event .fc-event-main .fc-total-event-cell {
        color: #fff;
        font-size: 14px;
        line-height: normal;
        background-color: var(--secondary-color);
        border: none;
        display: flex;
        border-radius: 4px !important;
        padding: 4px 5px;
        justify-content: center;
        cursor: pointer;
    }
    .fc-daygrid-day.fc-day-active .fc-h-event .fc-event-main .fc-total-event-cell {
        background-color: rgba(255,255,255,0.8);
        color: var(--primary-color);
    }
    .fc-icon {
        font-family: "bootstrap-icons" !important;
    }
    .fc-icon-chevron-left::before {
        content: '\F12F';
    }
    .fc-icon-chevron-right::before {
        content: '\F138';
    }
	.fc .fc-toolbar.fc-header-toolbar {
		margin-bottom: 10px;
	}
    .fc .fc-toolbar-title {
		font-size: 24px;
		margin: 0px;
		font-weight: 600;
		line-height: 36px;
		text-transform: capitalize;
		font-family: "Figtree", sans-serif;
	}
    .fc-toolbar-chunk >div {
        display: flex;
        align-items:center;
        gap: 20px;
    }
    .fc .fc-button-primary:hover, .fc .fc-button-primary, .fc .fc-button-primary:not(:disabled).fc-button-active, .fc .fc-button-primary:not(:disabled):active {
        background-color: transparent;
        border-color: transparent;
        color: var(--secondary-color);
        padding: 0;
    }
    .fc .fc-button-primary:focus, .fc .fc-button-primary:not(:disabled).fc-button-active:focus, .fc .fc-button-primary:not(:disabled):active:focus {
        box-shadow: none;
        outline: none;
    }
    .fc .fc-daygrid-day.fc-day-active .fc-daygrid-day-frame {
        background: var(--tertiary-color) !important;
    }
</style>