<?php 
    $title = get_field('title');
    $description = get_field('description');
    $buttonEnable = get_field('ukryj_przycisk');
    $button = get_field('nazwa_na_przycisku');
    $url = get_field('adres_przycisku');

    $atts = shortcode_atts(
        array(
            'post_type' => 'event',
            'posts_per_page' => -1,
            'categories' => 'event-category', // Default to no category filter
        ),
        $atts
    );

    $html_to_return = ''; // Initialize the variable

    ob_start();

    $post_type = sanitize_text_field($atts['post_type']);
    $posts_per_page = intval($atts['posts_per_page']);
    $posts_categories = intval($atts['categories']);

    $args = array(
        'post_type' => $post_type,
        'posts_per_page' =>$posts_per_page,
        'cat' =>  $posts_categories,
    );

    $custom_query = new WP_Query($args);
        $index = 0;
    $eventsArray = [];
    if ($custom_query->have_posts()) : 
        while ($custom_query->have_posts()) : 
            $custom_query->the_post();
            $rawDate = get_post_meta(get_the_ID(), 'event_date', true);
            // Reformat the date from YYYYMMDD to YYYY-MM-DD
            $formattedDate = DateTime::createFromFormat('Ymd', $rawDate)->format('Y-m-d');

            $eventsArray[] = [
                'title' => get_the_title(),
                'date' => $formattedDate,
                'time' => get_post_meta(get_the_ID(), 'event_time', true),
                'place' => get_post_meta(get_the_ID(), 'place', true)
            ];
    
        endwhile;
    endif;

    $eventsJson = json_encode($eventsArray);

    var_dump($eventsJson);
   
?>
<section class="calendar-section">
	<div class="container">
		<div class="row align-items-center">
			<div class="col-lg-4">
				<?php if( $title ) : ?>
				<h2><?php echo $title; ?></h2>
				<?php endif; ?>
				<?php if( $description ) : ?>
				<?php echo $description; ?>
				<?php endif; ?>

				<div class="events-detail"></div>
				<?php if( $buttonEnable ) : ?>
				<div class="web-btn d-flex my-4">
					<a href="<?php echo $url; ?>" class="link-btn">
						<span><?php echo esc_html_e($button, 'Kolejowe'); ?></span>
						<div class="icon">
							<img decoding="async" src="<?php echo get_template_directory_uri(); ?>/images/right-arrow-circle.svg" alt="icon" aria-hidden="true">
						</div>
					</a>
				</div>
				<?php endif; ?>
			</div>
			<div class="col-lg-8">
				<div id="calendar" class="event-calendar"></div>
			</div>
		</div>
		</div>
</section>
<script>
function initializeCalendar() {
    var eventsArray = <?php echo $eventsJson; ?>;
    // Transform eventsArray for FullCalendar
    var calendarEvents = eventsArray.map(event => ({
        title: event.title,
        start: event.date,
        extendedProps: {
            time: event.time,
            place: event.place
        }
    }));

    var calendarEl = document.getElementById('calendar');
    var calendar = new FullCalendar.Calendar(calendarEl, {
        themeSystem: 'bootstrap5',
        // emphasizes business hours
        businessHours: false,
        defaultView: 'month',
        // event dragging & resizing
        editable: true,
        // header
        headerToolbar: {
            left: 'prev, title',
            //center: 'month,agendaWeek,agendaDay',
            right: 'next'
        },
        events: calendarEvents,
        dateClick: function (info) {
            showEventsForDay(info.dateStr, calendarEvents);
        }
    });

    calendar.render();
}

// Show events for a specific day in the events-detail div
function showEventsForDay(date, events) {
    var eventsForDay = events.filter(event => event.start === date);
    console.log(events);
    console.log(date);

    var detailDiv = $('.events-detail');
    detailDiv.empty();

    if (eventsForDay.length > 0) {
        eventsForDay.forEach(event => {
            var eventHtml = `
                <div class="event-details">
                    <h6 class="event-title">${event.title}</h6>
                    <div class="event-bottom">
                        <div class="event-date"><span class="dashicons dashicons-calendar-alt"> </span><span class="text">${event.start}</span></div>
                        <div class="event-time"><span class="dashicons dashicons-clock"></span> <span class="text">${event.extendedProps.time}</span></div>
                        <div class="event-place"><span class="dashicons dashicons-location"> </span><span class="text">${event.extendedProps.place}</span></div>
                    </div>
                </div>
            `;
            detailDiv.append(eventHtml);
        });
    } else {
        detailDiv.append('<p>W wybranym dniu nie ma żadnych wydarzeń. Wybierz inny dzień.</p>');
    }
}

// Check if FullCalendar is loaded
function loadCalendarCustomScript() {
    //const checkInterval = setInterval(() => {
        if (typeof FullCalendar !== 'undefined') {
            initializeCalendar();
        } else {
            console.error('FullCalendar is not loaded!');
        }
    //}, 2000); // Check every 100ms

}
</script>