<?php 

// Template Name: Strony Subpage Template

 

get_header();

// Get the post thumbnail ID

$thumbnail_id = get_post_thumbnail_id( get_the_ID() );

// Get the alt text for the thumbnail image

$thumbnail_alt = get_post_meta( $thumbnail_id, '_wp_attachment_image_alt', true );

// Fallback to post title if alt text is not set

$alt_text = $thumbnail_alt ? $thumbnail_alt : '';

$featured_image = get_the_post_thumbnail(get_the_ID(), 'full',array('alt' => esc_attr($alt_text)));

?>

<section class="sub-page-header <?php if( $featured_image )  echo 'banner-header '; ?>">

	<div class="container">

		<div class="row">

			<div class="<?php if( $featured_image ) echo 'col-lg-6'; else echo 'col-12'; ?>">

				<?php custom_breadcrumbs(); ?>

				<div class="content template-excerpt">

					<div class="web-heading heading-divider secondary">
						<h1><?php the_title(); ?></h1>
					</div>
					<?php if (has_excerpt()): the_excerpt(); endif;?>
				</div>
			</div>

			<?php if( $featured_image ) : ?>

			<div class="col-lg-6">

				<div class="block-img featured-img-block">

					<?php echo $featured_image; ?>

				</div>

			</div>

			<?php endif; ?>

		</div>

		<div class="row mt-4">

            <div class="col-lg-9 article-page-content template-content">

                <?php the_content();?> 

            </div>

            <div class="col-lg-3 article-page-sidebar">

                <div class="web-heading">

                    <?php

	                    // Get the parent page ID

	                    $parent_id = wp_get_post_parent_id(get_the_ID());

	                    // If there's no parent, use the current page as the parent

	                    if (!$parent_id) {

	                        $parent_id = get_the_ID();

	                    }

	                    // Get the parent page title

	                    $parent_title = get_the_title($parent_id);

	                ?>

	                <h2><?php echo esc_html($parent_title); ?></h2>

                </div>

                <?php

	                // Define the fetch_svg_content function if it doesn't already exist

	                if (!function_exists('fetch_svg_content')) {

	                    function fetch_svg_content($url) {

	                        $response = wp_remote_get($url);

	                        if (is_wp_error($response)) {

	                            return ''; // Return empty if there's an error

	                        }

	                        return wp_remote_retrieve_body($response);

	                    }

	                }



	                // Get sibling pages (pages with the same parent)

	                $siblings = get_pages(array(

	                    'child_of' => $parent_id,

	                    'sort_column' => 'menu_order'

	                ));



	                // Loop through sibling pages

	                foreach ($siblings as $sibling) {

	                    $sibling_id = $sibling->ID;

	                    $sibling_title = $sibling->post_title;

	                    $sibling_link = get_permalink($sibling_id);

	                    $icon_url = get_post_meta($sibling_id, '_custom_icon_url', true);

	                    $show_icon = get_post_meta($sibling_id, '_custom_show_icon', true);



	                    // Fetch SVG content if needed

	                    $svg_content = '';

	                    if (!empty($icon_url)) {

	                        $file_extension = pathinfo($icon_url, PATHINFO_EXTENSION);

	                        if ($file_extension === 'svg') {

	                            $svg_content = '<img class="svg" src="' . esc_url($icon_url) . '" alt="SVG Image">';

	                        }

	                    }

                ?>

                <div class="web-btn two-icon-btn mb-3 d-flex">

                    <a href="<?php echo esc_url($sibling_link); ?>" class="link-btn">

                        <div class="icon img-svg">

                            <?php echo $svg_content; // Output the SVG content directly ?>

                        </div>    

                        <span><?php echo esc_html($sibling_title); ?></span>

                        <div class="icon icon-right">

                            <svg width="20" height="18" viewBox="0 0 20 18" fill="none" xmlns="http://www.w3.org/2000/svg">

                                <path d="M0 8.68066H18M18 8.68066L10.4062 0.680664M18 8.68066L10.4062 16.6807" stroke="#042B60" stroke-width="2"/>

                            </svg>



                            <!-- <img decoding="async" src="<?php echo get_template_directory_uri() ?>/images/arrow-right.svg" alt="icon" aria-hidden="true"> -->

                        </div>    

                    </a>

                </div>

                <?php } ?>

            </div>

        </div>

	</div>

</section>



<?php get_footer(); ?>